<?php

namespace App\Http\Controllers;
use App\Models\FormData;
use Illuminate\Http\Request;
use App\Http\Requests\StoreFormDataRequest;

class FormDataController extends Controller
{
    
    public function __construct()
    {
        $this->middleware('auth')->except(['index', 'show','dashboard','edit','create']);
    }

    public function index(Request $request)
    {

        $query = \App\Models\FormData::query();
        
        
        // Apply monthly income filter if provided
        if ($request->has('monthly_income') && $request->monthly_income !== null) {

            $query->where('monthly_income', $request->monthly_income);
        }

        // Apply region filter if provided
        if ($request->filled('region')) {
            $query->where('region', 'LIKE', '%' . $request->region . '%');
        }

        // Filter by children_below_2 if provided
        if ($request->filled('children_below_2')) {
            $query->where('children_below_2', $request->children_below_2);
        }

        // Filter by children_from_2_6 if provided
        if ($request->filled('children_from_2_6')) {
            $query->where('children_from_2_6', $request->children_from_2_6);
        }

        // Filter by children_primary if provided
        if ($request->filled('children_primary')) {
            $query->where('children_primary', $request->children_primary);
        }

        // Filter by children_secondary if provided
        if ($request->filled('children_secondary')) {
            $query->where('children_secondary', $request->children_secondary);
        }

        // Filter by children_high_school if provided
        if ($request->filled('children_high_school')) {
            $query->where('children_high_school', $request->children_high_school);
        }

        // Filter by children_university if provided
        if ($request->filled('children_university')) {
            $query->where('children_university', $request->children_university);
        }


        // Filter by health_conditions if provided
        if ($request->filled('health_conditions')) {
            $query->where('health_conditions', $request->health_conditions);
        }

        $formDatas = $query->paginate(10);

        return view('form_data.index', compact('formDatas'));
    }

    public function dashboard()
    {
        // Summing up numerical fields
        $totalFamily = FormData::count();
        $totalFamilyMembers = FormData::sum('family_members');
        $totalChildrenBelow2 = FormData::sum('children_below_2');
        $totalChildrenFrom2To6 = FormData::sum('children_from_2_6');
        $totalChildrenPrimary = FormData::sum('children_primary');
        $totalChildrenSecondary = FormData::sum('children_secondary');
        $totalChildrenHighSchool = FormData::sum('children_high_school');

        $totalSum = $totalFamilyMembers + $totalChildrenBelow2 + 
                    $totalChildrenFrom2To6 + $totalChildrenPrimary + 
                    $totalChildrenSecondary + $totalChildrenHighSchool;

        // Fetching data for charts
        $healthConditions = FormData::selectRaw('health_conditions, COUNT(*) as count')
            ->groupBy('health_conditions')
            ->pluck('count', 'health_conditions');

        $monthlyIncome = FormData::selectRaw('monthly_income, COUNT(*) as count')
            ->groupBy('monthly_income')
            ->pluck('count', 'monthly_income');

        $maritalStatus = FormData::selectRaw('marital_status, COUNT(*) as count')
            ->groupBy('marital_status')
            ->pluck('count', 'marital_status');

        return view('form_data.dashboard', compact(
            'totalSum',
            'totalFamilyMembers',
            'totalChildrenBelow2',
            'totalChildrenFrom2To6',
            'totalChildrenPrimary',
            'totalChildrenSecondary',
            'totalChildrenHighSchool',
            'healthConditions',
            'monthlyIncome',
            'maritalStatus',
            'totalFamily'
        ));
    }

    

    public function create()
    {
        if (!auth()->check()) {
            return redirect()->route('auth.login')->with('error', 'يجب تسجيل الدخول');
        }
        return view('form_data.create');
    }

    public function store(StoreFormDataRequest $request)
    {
        // dd(auth()->user()); // Check if user is authenticated
        // Get the validated data from the request
        $validated = $request->validated();
        
        // Debugging: Check if the user is authenticated
        if (auth()->check()) {
            $validated['user_id'] = auth()->id();
        } else {
            return redirect()->route('auth.login')->with('error', 'يجب تسجيل الدخول');
        }


        // Create a new FormData record using the validated data
        FormData::create($validated);

        return redirect()->route('form_data.index')->with('success', 'تم إضافة البيانات بنجاح');
    }

    public function show(FormData $formData)
    {
        return view('form_data.show', compact('formData'));
    }

    public function edit(FormData $formData)
    {
        return view('form_data.edit', compact('formData'));
    }

    public function update(StoreFormDataRequest $request, FormData $formData)
    {
        $validated = $request->validated();

        $formData->update($validated);

        return redirect()->route('form_data.index')->with('success', 'تم تحديث البيانات بنجاح');
    }

    public function destroy(FormData $formData)
    {
        $formData->delete();

        return redirect()->route('form_data.index')->with('success', 'تم حذف البيانات بنجاح');
    }
}
